[![Build Status](https://travis-ci.org/dizak/prwlr.svg?branch=master)](https://travis-ci.org/dizak/prwlr)


# prwlr

prwlr (*profiles crawler*) integrates **Genetic Interactions** and **Phylogenetic Profiles**.
prwlr aimes to be self-contained (as far as possible) and easy-to-use python library.
